/* Copyright IBM Corp. 2012  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.services.ServiceManager");

//<INTERFACE>
/**
 * This interface manages services that are provided to the system, i.e. to iWidgets and other components.<br/>
 * It provides capability to access Services in Lotus Mashups. <br/>
 * By default EventService and ConfigService are provided.<br/>
 * Page components are able to use event services by using following api:<p/>
 * <code>var eventService = com.ibm.mashups.services.ServiceManager.getService(<br/>
 * &nbsp;&nbsp;&nbsp;&nbsp;com.ibm.mashups.iwidget.services.EventService.SERVICE_NAME);</code><br/>
 * <p/><p/>
 * <b>Configuration of services:</b><br/>
 * This section describes how each service is configured and  how additional services can be added.<p/>
 * 
 * Through the ConfigService.properties one can define an additional property named "additionalServices" 
 * defining additional services besides EventService and ConfigService.<p/>
 * Each entry should have the following format.<p />
 * <code>"name": service name.</code><br/>
 * <code>"path": url that point to the service js file.</code><br/>
 * <code>"baseClass": the class that implements the service. one instance of this class will be generated.</code><br />
 * <p/>
 * Example:<br/>
 *  &nbsp;&nbsp;&nbsp;additionalServices = [<br/>
 *  &nbsp;&nbsp;&nbsp;{ "name":"SecurityService",<br/>
 *  &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"path":"/mum/js/com/ibm/enabler/iw/securityservices.js",<br/>
 *  &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"baseClass":"com.ibm.mm.iwidget.services.SecurityService"}<br/> 
 *  &nbsp;&nbsp;&nbsp;] <p />
 *
 * @ibm-spi
 * @ibm-module Base2
 */
dojo.declare("com.ibm.mashups.services.ServiceManager",null,
  {
    /**
     * @private
     */
    constructor:function(){
    },
    /**
    This interface allow page components to get the required service.
    @param{String} serviceName required service name that's used to uniquely identify a service .
    @type Object
    @returns{Object} an instance of required service. NULL if configured incorrectly.
    */
    getService:function(serviceName) {
    }
  }
);
//</INTERFACE>

dojo.require("com.ibm.mm.services.ServiceManagerImpl");
